@@ -1,16 +1,18 @@
 <?php
 
+declare(strict_types=1);
+
 namespace GuzzleHttp\Promise\Tests;
 
 use GuzzleHttp\Promise\RejectionException;
 use PHPUnit\Framework\TestCase;
 
 /**
- * @covers GuzzleHttp\Promise\RejectionException
+ * @covers \GuzzleHttp\Promise\RejectionException
  */
 class RejectionExceptionTest extends TestCase
 {
-    public function testCanGetReasonFromException()
+    public function testCanGetReasonFromException(): void
     {
         $thing = new Thing1('foo');
         $e = new RejectionException($thing);
@@ -19,10 +21,10 @@ class RejectionExceptionTest extends TestCase
         $this->assertSame('The promise was rejected with reason: foo', $e->getMessage());
     }
 
-    public function testCanGetReasonMessageFromJson()
+    public function testCanGetReasonMessageFromJson(): void
     {
         $reason = new Thing2();
         $e = new RejectionException($reason);
-        $this->assertStringContainsString("{}", $e->getMessage());
+        $this->assertStringContainsString('{}', $e->getMessage());
     }
 }
