@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace GuzzleHttp\Promise\Tests;
 
 use GuzzleHttp\Promise\TaskQueue;
@@ -7,26 +9,26 @@ use PHPUnit\Framework\TestCase;
 
 class TaskQueueTest extends TestCase
 {
-    public function testKnowsIfEmpty()
+    public function testKnowsIfEmpty(): void
     {
         $tq = new TaskQueue(false);
         $this->assertTrue($tq->isEmpty());
     }
 
-    public function testKnowsIfFull()
+    public function testKnowsIfFull(): void
     {
         $tq = new TaskQueue(false);
-        $tq->add(function () {});
+        $tq->add(function (): void {});
         $this->assertFalse($tq->isEmpty());
     }
 
-    public function testExecutesTasksInOrder()
+    public function testExecutesTasksInOrder(): void
     {
         $tq = new TaskQueue(false);
         $called = [];
-        $tq->add(function () use (&$called) { $called[] = 'a'; });
-        $tq->add(function () use (&$called) { $called[] = 'b'; });
-        $tq->add(function () use (&$called) { $called[] = 'c'; });
+        $tq->add(function () use (&$called): void { $called[] = 'a'; });
+        $tq->add(function () use (&$called): void { $called[] = 'b'; });
+        $tq->add(function () use (&$called): void { $called[] = 'c'; });
         $tq->run();
         $this->assertSame(['a', 'b', 'c'], $called);
     }
